import os
import re
import uuid
from core.encoder import ComplexEncoder

env = os.getenv('ENV', 'localdev')

# Hack to enable ThreatHunter to call dashboard from CSR
dashboard_urls = {
    "localdev": "http://psc.gateway:8900",
    "dev01": "https://defense-dev01.cbdtest.io",
    "dev04": "https://defense-dev04.cbdtest.io",
    "dev05": "https://defense-dev05.cbdtest.io",
    "dev08": "https://defense-dev08.cbdtest.io",
    "dev10": "https://defense-dev10.cbdtest.io",
    "hub02": "https://defense-hub02.cbdtest.io",
    "hub-dev-us": "https://defense-hub-dev-us.cbdtest.io",
    "hub04": "https://defense-hub04.cbdtest.io",
    "hub-prod-us": "https://defense-hub-prod-us.conferdeploy.net",
    "hub-prod-eu": "https://defense-hub-prod-eu.conferdeploy.net",
    "hub-prod-ap": "https://defense-hub-prod-ap.conferdeploy.net",
    "hub-prod-ap2": "https://defense-hub-prod-ap2.conferdeploy.net",
    "test02": "https://defense-test02.cbdtest.io",
    "test03": "https://defense-test03.cbdtest.io",
    "eap01": "https://defense-eap01.conferdeploy.net",
    "prod01": "https://dashboard.confer.net",
    "prod02": "https://defense.conferdeploy.net",
    "prod03": "https://comcast.conferdeploy.net",
    "prod04": "https://blackrock.confer.net",
    "prod05": "https://defense-prod05.conferdeploy.net",
    "prod06": "https://defense-eu.conferdeploy.net",
    "prodnrt": "https://defense-prodnrt.conferdeploy.net",
    "prodsyd": "https://defense-prodsyd.conferdeploy.net"
}


class RequestContext(object):
    def __init__(self):
        self.gateway_ip = None
        self.gateway_port = None
        self.gateway_csr_port = None
        self.gateway_authenticated_port = None
        self.client_ip = None
        self.correlation_id = str(uuid.uuid4())
        self.origin_env = env
        self.gateway_public_url = None
        self.th_gateway_url = dashboard_urls[env]

    def json(self):
        return ComplexEncoder().encode(self)

    def set_origin_env(self, origin_host):
        match = re.match(r'.*csr-([-a-z0-9A-Z]+)\.', origin_host)
        match = match or re.match(r'.*defense-([-a-z0-9A-Z]+)\.', origin_host)
        match = match or re.match(r'.*api-([-a-z0-9A-Z]+)\.', origin_host)
        origin_env = "localdev"
        if match:
            origin_env = match.group(1)

        if 'blackrock' in origin_host:
            origin_env = "prod04"
        if 'defense-eu' in origin_host:
            origin_env = "prod06"
        if origin_host in ['dashboard.confer.net', 'csr.defense.carbonblack.io', 'csr.bit9.local']:
            origin_env = "prod01"
        if origin_host in ['defense.conferdeploy.net', 'api5.conferdeploy.net']:
            origin_env = "prod02"
        self.origin_env = origin_env
        self.th_gateway_url = dashboard_urls.get(origin_env, None)

    @staticmethod
    def parse(json):
        ctx = RequestContext()
        if not json.get('client_ip'):
            json['client_ip'] = None
        if not json.get('origin_env'):
            json['origin_env'] = env
        if not json.get('correlation_id'):
            json['correlation_id'] = str(uuid.uuid4())
        if not json.get('gateway_authenticated_port'):
            json['gateway_authenticated_port'] = 8900
        if not json.get('gateway_csr_port'):
            json['gateway_csr_port'] = 8903
        ctx.__dict__ = json
        return ctx
