from core.encoder import ComplexEncoder
from models.user_context import UserContext
from models.call_context import CallContext


class SessionContext(object):
    def __init__(self,
                 call_context=None,
                 user_context=None,
                 user_info=None,
                 authenticated=False,
                 xcsrf=None,
                 client_ip=None,
                 auth_id=None,
                 origin_env=None):
        self.call_context = call_context or CallContext()
        self.user_context = user_context or UserContext()
        self.user_info = user_info or {}
        self.authenticated = authenticated
        self.xcsrf = xcsrf
        self.client_ip = client_ip
        self.auth_id = auth_id
        self.origin_env = origin_env

    def json(self):
        return ComplexEncoder().encode(self)

    @staticmethod
    def parse(json):
        session_ctx = SessionContext(
            user_context=UserContext.parse(json),
            call_context=CallContext.parse(json),
            user_info=json['user_info'],
            authenticated=json['authenticated'],
            xcsrf=json['xcsrf'],
            client_ip=json.get('client_ip'),
            auth_id=json.get('auth_id'),
            origin_env=json.get('origin_env')
        )
        return session_ctx
