import os


class HelperService(object):
    gateway_port = os.getenv('GATEWAY_PORT')

    def __init__(self):
        pass

    def get_headers_copy(self, source_headers, *drop_headers):
        if source_headers is None:
            return None

        headers = {}
        uname_key = ''
        uname_value = ''
        cookie_header = ''

        for key in source_headers.keys():
            headers[key] = source_headers[key]

        for header in drop_headers:
            if header == 'Cookie':
                cookie_header = headers.get('Cookie')
                break

        if cookie_header:
            for cookie in cookie_header.split(";"):
                if 'uname' in cookie:
                    uname_cookie = cookie.split("=")
                    uname_key = uname_cookie[0]
                    uname_value = uname_cookie[1]
                    break

        for key in drop_headers:
            headers.pop(key, None)

        if uname_key:
            headers[uname_key.strip()] = uname_value

        return headers

    def get_gateway_url(self, gateway_ip, port=gateway_port):
        return 'http://{gateway_ip}:{gateway_port}'.format(gateway_ip=gateway_ip, gateway_port=port)

    def remove_chunked_header(self, headers):
        if headers.get('Transfer-Encoding') == 'chunked':
            del headers['Transfer-Encoding']
        return headers

    def get_rbac_key_access_permissions(self, target_auth_id, permissions):
        result = [
            {
                "name": "org.{}".format(self._get_auth_entity_permission_type(target_auth_id)),
                "actions": permissions
            }
        ]
        return result

    def _get_auth_entity_permission_type(self, auth_id):
        # auth ID is a connector ID if it can be parsed as an int, otherwise a user
        try:
            int(auth_id)
            return "users"
        except ValueError:
            if len(auth_id) != 10:
                # It is possible to have a connector ID with only numbers, so make sure it is 10 characters as wel
                return "users"
            return "connectors"

    # Returns True if the request URL is an is_authenticated url (CSRF exempted authentication check)
    def is_csrf_exempt_authenticated_request(request):
        requested_url = request.headers.get('X-Forwarded-Uri') or request.url_rule.rule
        return (requested_url == '/isauthenticated' or requested_url == '/auth/v1/sessions/current') and \
            request.method == 'GET'
