import json
import os
import yaml
import sys
from psc_orgkey import decode_orgkey, InvalidOrgKeyError

# In the Request Body of PUT /auth/v1/sessions/current :
# 1. Only org_id - Process the request
# 2. Only org_key - decode org_id from org_key and process the request
# 3. If both org_id & org_key - decode org_id from org_key
# 	a. If org_id and decoded org_id matches -> Process the request
# 	b. If they don't match -> Return Bad request
#


def get_org_id_from_request(request):
    org_id = extract_org_id(request)
    decoded_org_id = extract_org_id_from_org_key(request)

    if (not org_id or org_id.isspace()) and (not decoded_org_id or decoded_org_id.isspace()):
        # No org_id in request, orgKey is also not valid: Bad request scenario
        raise ValueError("Invalid Org details")
    elif not org_id or org_id.isspace():
        return decoded_org_id
    elif not decoded_org_id or decoded_org_id.isspace():
        return org_id
    elif org_id != decoded_org_id:
        # org_id & org_key both in request, but not matching: Bad request
        raise ValueError("Invalid Org details")
    else:
        return org_id


def is_host_from_env(host, env):
    env_urls = yaml.load(open(os.path.join(os.path.dirname(__file__), 'url_configs.yml')), Loader=yaml.BaseLoader)[env]
    for url_type in env_urls:
        if host in env_urls[url_type]:
            return True
    return False


# if org_key in request body, decode the org_key and get corresponding org_id value
def extract_org_id_from_org_key(request):
    decoded_org_id = ''
    try:
        org_key = json.loads(request.data)['org_key']
        org_key_decoded = decode_orgkey(str(org_key))
        decoded_org_id = str(org_key_decoded.org_id)
        org_key_env = org_key_decoded.env
        correct_env = is_host_from_env(request.host, org_key_env)

        if not correct_env:
            raise InvalidOrgKeyError
    except KeyError:
        pass
    except InvalidOrgKeyError:
        raise ValueError("Invalid Org details")
    return decoded_org_id


def extract_org_id(request):
    org_id = ''
    try:
        org_id = json.loads(request.data)['org_id']
        org_id = str(org_id)
    except KeyError:
        pass
    return org_id
